// vim: set tw=80 ts=4 sw=4 sts=4:
/*
    This file is part of Accountant.

    Accountant is free software: you can redistribute it and/or modify
    it under the terms of the GNU Affero General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    Accountant is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Affero General Public License for more details.

    You should have received a copy of the GNU Affero General Public License
    along with Accountant.  If not, see <http://www.gnu.org/licenses/>.
 */
/* jshint node: true */
'use strict';

var moment = require('moment'),
    c3     = require('c3');

var angular = require('angular');

var ngResource = require('angular-resource');


var balanceChartModule = angular.module('balanceChartModule', [
    ngResource
])

.component('balanceChart', {
    template: '<div></div>',
    bindings: {
        minDate: '<',
        maxDate: '<'
    },
    controller: function($routeParams, Balances, $element, $log) {
        var vm = this;

        vm.loadData = function() {
            Balances.query({
                id: $routeParams.accountId,
                //begin: vm.minDate.format('YYYY-MM-DD'),
                //end: vm.maxDate.format('YYYY-MM-DD')
            }, function(results) {
                var headers = [['x', 'balances', 'expenses', 'revenues']];

                var rows = results.map(function(result) {
                    return [
                        result.operation_date,
                        result.balance,
                        result.revenues,
                        result.expenses
                    ];
                });

                vm.chart.load({
                    rows: headers.concat(rows)
                });
            });
        };

        vm.$onInit = function() {
            $log.log($element);

            vm.chart = c3.generate({
                //bindto: $element[0],
                bindto: $element[0].children[0],
                size: {
                    height: 500,
                //    witdh: 800,
                },
                data: {
                    x: 'x',
                    rows: [],
                    axes: {
                        expenses: 'y2',
                        revenues: 'y2'
                    },
                    type: 'bar',
                    types: {
                        balances: 'area'
                    },
                    groups: [
                        ['expenses', 'revenues']
                    ]
                },
                axis: {
                    x: {
                        type: 'timeseries',
                        tick: {
                            format: '%Y-%m-%d',
                            rotate: 50,
                        }
                    },
                    y: {
                        label: {
                            text: 'Amount',
                            position: 'outer-middle'
                        }
                    },
                    y2: {
                        show: true,
                        label: {
                            text: 'Amount',
                            position: 'outer-middle'
                        }
                    }
                },
                grid: {
                    x: {
                        show: true,
                    },
                    y: {
                        show: true,
                        lines: [
                            { value: 0, axis: 'y2' },
                            { value: 0, axis: 'y', class: 'zeroline'}
                        ]
                    }
                },
                tooltip: {
                    format: {
                        value: function(value, ratio, id, index) {
                            return value + '€';
                        }
                    }
                },
                subchart: {
                    show: true
                }
            });

            vm.loadData();
        };

        vm.$onChange = function(changes) {
            vm.loadData();
        };
    }
}).factory('Balances', function($resource) {
    return $resource(
        '/api/account/:id/daily_balances', {
            id: '@id'
        }
    );
});

module.exports = balanceChartModule;
